{
  pkgs,
  config,
  lib,
  ...
}: let
  inherit (import ../lib.nix {}) mkSimpleTrayService;
in {
  imports = [
      ../profiles/wayland-desktop.nix
  ];

  home.packages = with pkgs; [
    swayidle
    swaylock

    # fonts
    noto-fonts
    font-awesome
    noto-fonts-emoji
  ];

  wayland.windowManager.sway = {
    enable = true;
    systemdIntegration = true;

    config = let 
      modifier = "Mod4";
    in {
      inherit modifier;

      keybindings = lib.mkOptionDefault {
        "${modifier}+Ctrl+l" = "exec ${pkgs.swaylock}/bin/swaylock -fF";
        "XF86AudioPlay" = "exec ${pkgs.playerctl}/bin/playerctl play-pause";
        "XF86AudioPrev" = "exec ${pkgs.playerctl}/bin/playerctl previous";
        "XF86AudioNext" = "exec ${pkgs.playerctl}/bin/playerctl next";
      };

      terminal = "alacritty";
      startup = [
        # Launch Firefox on start
        # {command = "firefox";}
        # {command = "gnome-keyring --replace"}
      ];


      fonts = {
        names = [ "Noto Sans" "Font Awesome 5 Free" ];
        style = "Heavy";
        size = 10.0;
      };


      #fonts = {
      #  names = [ "DejaVu Sans Mono" "FontAwesome5Free" ];
      #  style = "Bold Semi-Condensed";
      #  size = 11.0;
      #};

      colors.focused = {
        childBorder = "#ffa500";

        # border = "#ffa500";

        # TODO: refer to the defaults for these
        border = "#4c7899";
        background = "#285577";
        text = "#ffffff";
        indicator = "#2e9ef4";
      };

      window = {
        border = 4;
      };
    };
  };

  services.swayidle = {
    enable = true;
    timeouts = [
      { timeout = 60 * 5; command = "${pkgs.swaylock}/bin/swaylock -fF"; }
    ];
  };
}
